/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: InternalDataSource.java 464373 2006-10-16 04:21:54Z rahul $
 */

package org.apache.shale.examples.sqlbrowser;

import java.sql.Connection;
import java.sql.SQLException;
import org.apache.derby.jdbc.EmbeddedDataSource;

/**
 * <p>Trivial implementation of <code>DataSource</code> that wraps a data source
 * provided by Derby, and provides a shutdown hook.</p>
 */
public class InternalDataSource extends EmbeddedDataSource {


    // ------------------------------------------------------------ Constructors


    /**
     * <p>Construct a connection pool for the specified URL.</p>
     */
    public InternalDataSource(String url) throws SQLException {

        // Instantiate and configure a Derby EmbeddedDataSource
        setDatabaseName(url);
        setCreateDatabase("create");

    }


    // ---------------------------------------------------------- Public Methods


    /**
     * <p>Cause the embedded Derby database to be shut down.</p>
     */
    public void shutdown() throws SQLException {

        setShutdownDatabase("shutdown");
        Connection conn = null;
        try {
            conn = getConnection();
        } catch (SQLException e) {
            ; // Ignore errors here; we just wanted to trigger the shutdown
        } finally {
            try {
                if (conn != null) {
                    conn.close();
                }
            } catch (SQLException e) {
                ;
            }
        }

    }


}
